# SMILES Pair Encoding.
> SMILES Pair Encoding (SmilesPE) trains a substructure tokenizer from a large set of SMILES strings (e.g., ChEMBL) based on [byte-pair-encoding (BPE)](https://www.aclweb.org/anthology/P16-1162/).


## Install

`pip install your_project_name`

## Use the Pre-trained 

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


